# coding: utf-8

# django
from django.contrib import admin

# 3rd party
from reversion.admin import VersionAdmin

# app
from . import models


#
#   Group
#
class GroupAdmin(VersionAdmin):
    list_display = ('name', 'order', )
    list_display_links = ('name', )
    list_editable = ('order', )

    prepopulated_fields = {"slug": ("name",)}

    fieldsets = [
        (None, {
            'fields': ('name', 'slug', 'order', )
        }),
    ]

admin.site.register(models.Group, GroupAdmin)


#
#   Project
#
class ProjectImageInline(admin.TabularInline):
    model = models.ProjectImage


class ProjectAdmin(VersionAdmin):
    list_display = ('title', 'date', 'group', 'company', 'role', 'visible', )
    list_editable = ('visible', )
    inlines = (ProjectImageInline, )

    prepopulated_fields = {"slug": ("title",)}

    fieldsets = [
        ('General', {
            'fields': ('group', ('title', 'slug'), ('company', 'role'), 'date', ('stack', 'url', 'visible'), 'description')
        })
    ]

admin.site.register(models.Project, ProjectAdmin)
